diff lisp/vc-hooks.el @ 82145:f04985ac29f2

* vc-git.el: Relicense to GPLv3 or later. (vc-directory-exclusion-list, vc-handled-backends): Remove. * vc-hooks.el (vc-handled-backends): Add GIT. * vc.el (vc-directory-exclusion-list): Add .git. * vc2-xtra.texi (Customizing VC): Add GIT.
author Dan Nicolaescu <dann@ics.uci.edu>
date Thu, 26 Jul 2007 18:44:39 +0000
parents b98604865ea0
children 58ac5a791dfa f55f9811f5d7
line wrap: on
line diff
--- a/lisp/vc-hooks.el	Thu Jul 26 17:26:08 2007 +0000
+++ b/lisp/vc-hooks.el	Thu Jul 26 18:44:39 2007 +0000
@@ -62,9 +62,9 @@
   :type 'regexp
   :group 'vc)
 
-(defcustom vc-handled-backends '(RCS CVS SVN SCCS BZR HG Arch MCVS)
-  ;; BZR, HG, Arch and MCVS come last because they are per-tree rather
-  ;; than per-dir.
+(defcustom vc-handled-backends '(RCS CVS SVN SCCS BZR GIT HG Arch MCVS)
+  ;; BZR, GIT, HG, Arch and MCVS come last because they are per-tree
+  ;; rather than per-dir.
   "List of version control backends for which VC will be used.
 Entries in this list will be tried in order to determine whether a
 file is under that sort of version control.